/****************************************************************************
** Meta object code from reading C++ file 'dolphintabwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/dolphin-17.08.3/src/dolphintabwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dolphintabwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DolphinTabWidget_t {
    QByteArrayData data[35];
    char stringdata0[436];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DolphinTabWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DolphinTabWidget_t qt_meta_stringdata_DolphinTabWidget = {
    {
QT_MOC_LITERAL(0, 0, 16), // "DolphinTabWidget"
QT_MOC_LITERAL(1, 17, 17), // "activeViewChanged"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 21), // "DolphinViewContainer*"
QT_MOC_LITERAL(4, 58, 13), // "viewContainer"
QT_MOC_LITERAL(5, 72, 15), // "tabCountChanged"
QT_MOC_LITERAL(6, 88, 5), // "count"
QT_MOC_LITERAL(7, 94, 17), // "rememberClosedTab"
QT_MOC_LITERAL(8, 112, 3), // "url"
QT_MOC_LITERAL(9, 116, 5), // "state"
QT_MOC_LITERAL(10, 122, 17), // "currentUrlChanged"
QT_MOC_LITERAL(11, 140, 19), // "openNewActivatedTab"
QT_MOC_LITERAL(12, 160, 10), // "primaryUrl"
QT_MOC_LITERAL(13, 171, 12), // "secondaryUrl"
QT_MOC_LITERAL(14, 184, 10), // "openNewTab"
QT_MOC_LITERAL(15, 195, 15), // "openDirectories"
QT_MOC_LITERAL(16, 211, 11), // "QList<QUrl>"
QT_MOC_LITERAL(17, 223, 4), // "dirs"
QT_MOC_LITERAL(18, 228, 9), // "splitView"
QT_MOC_LITERAL(19, 238, 9), // "openFiles"
QT_MOC_LITERAL(20, 248, 5), // "files"
QT_MOC_LITERAL(21, 254, 8), // "closeTab"
QT_MOC_LITERAL(22, 263, 5), // "index"
QT_MOC_LITERAL(23, 269, 15), // "activateNextTab"
QT_MOC_LITERAL(24, 285, 15), // "activatePrevTab"
QT_MOC_LITERAL(25, 301, 32), // "slotPlacesPanelVisibilityChanged"
QT_MOC_LITERAL(26, 334, 7), // "visible"
QT_MOC_LITERAL(27, 342, 16), // "restoreClosedTab"
QT_MOC_LITERAL(28, 359, 9), // "detachTab"
QT_MOC_LITERAL(29, 369, 12), // "tabDropEvent"
QT_MOC_LITERAL(30, 382, 3), // "tab"
QT_MOC_LITERAL(31, 386, 11), // "QDropEvent*"
QT_MOC_LITERAL(32, 398, 5), // "event"
QT_MOC_LITERAL(33, 404, 13), // "tabUrlChanged"
QT_MOC_LITERAL(34, 418, 17) // "currentTabChanged"

    },
    "DolphinTabWidget\0activeViewChanged\0\0"
    "DolphinViewContainer*\0viewContainer\0"
    "tabCountChanged\0count\0rememberClosedTab\0"
    "url\0state\0currentUrlChanged\0"
    "openNewActivatedTab\0primaryUrl\0"
    "secondaryUrl\0openNewTab\0openDirectories\0"
    "QList<QUrl>\0dirs\0splitView\0openFiles\0"
    "files\0closeTab\0index\0activateNextTab\0"
    "activatePrevTab\0slotPlacesPanelVisibilityChanged\0"
    "visible\0restoreClosedTab\0detachTab\0"
    "tabDropEvent\0tab\0QDropEvent*\0event\0"
    "tabUrlChanged\0currentTabChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DolphinTabWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      22,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  124,    2, 0x06 /* Public */,
       5,    1,  127,    2, 0x06 /* Public */,
       7,    2,  130,    2, 0x06 /* Public */,
      10,    1,  135,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    0,  138,    2, 0x0a /* Public */,
      11,    2,  139,    2, 0x0a /* Public */,
      11,    1,  144,    2, 0x2a /* Public | MethodCloned */,
      14,    2,  147,    2, 0x0a /* Public */,
      14,    1,  152,    2, 0x2a /* Public | MethodCloned */,
      15,    2,  155,    2, 0x0a /* Public */,
      19,    2,  160,    2, 0x0a /* Public */,
      21,    0,  165,    2, 0x0a /* Public */,
      21,    1,  166,    2, 0x0a /* Public */,
      23,    0,  169,    2, 0x0a /* Public */,
      24,    0,  170,    2, 0x0a /* Public */,
      25,    1,  171,    2, 0x0a /* Public */,
      27,    1,  174,    2, 0x0a /* Public */,
      28,    1,  177,    2, 0x08 /* Private */,
      11,    1,  180,    2, 0x08 /* Private */,
      29,    2,  183,    2, 0x08 /* Private */,
      33,    1,  188,    2, 0x08 /* Private */,
      34,    1,  191,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::QUrl, QMetaType::QByteArray,    8,    9,
    QMetaType::Void, QMetaType::QUrl,    8,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl, QMetaType::QUrl,   12,   13,
    QMetaType::Void, QMetaType::QUrl,   12,
    QMetaType::Void, QMetaType::QUrl, QMetaType::QUrl,   12,   13,
    QMetaType::Void, QMetaType::QUrl,   12,
    QMetaType::Void, 0x80000000 | 16, QMetaType::Bool,   17,   18,
    QMetaType::Void, 0x80000000 | 16, QMetaType::Bool,   20,   18,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   26,
    QMetaType::Void, QMetaType::QByteArray,    9,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 31,   30,   32,
    QMetaType::Void, QMetaType::QUrl,    8,
    QMetaType::Void, QMetaType::Int,   22,

       0        // eod
};

void DolphinTabWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DolphinTabWidget *_t = static_cast<DolphinTabWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->activeViewChanged((*reinterpret_cast< DolphinViewContainer*(*)>(_a[1]))); break;
        case 1: _t->tabCountChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->rememberClosedTab((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 3: _t->currentUrlChanged((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 4: _t->openNewActivatedTab(); break;
        case 5: _t->openNewActivatedTab((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2]))); break;
        case 6: _t->openNewActivatedTab((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 7: _t->openNewTab((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2]))); break;
        case 8: _t->openNewTab((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 9: _t->openDirectories((*reinterpret_cast< const QList<QUrl>(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 10: _t->openFiles((*reinterpret_cast< const QList<QUrl>(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 11: _t->closeTab(); break;
        case 12: _t->closeTab((*reinterpret_cast< const int(*)>(_a[1]))); break;
        case 13: _t->activateNextTab(); break;
        case 14: _t->activatePrevTab(); break;
        case 15: _t->slotPlacesPanelVisibilityChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->restoreClosedTab((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 17: _t->detachTab((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->openNewActivatedTab((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->tabDropEvent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QDropEvent*(*)>(_a[2]))); break;
        case 20: _t->tabUrlChanged((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 21: _t->currentTabChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (DolphinTabWidget::*_t)(DolphinViewContainer * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DolphinTabWidget::activeViewChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (DolphinTabWidget::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DolphinTabWidget::tabCountChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (DolphinTabWidget::*_t)(const QUrl & , const QByteArray & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DolphinTabWidget::rememberClosedTab)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (DolphinTabWidget::*_t)(const QUrl & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DolphinTabWidget::currentUrlChanged)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject DolphinTabWidget::staticMetaObject = {
    { &QTabWidget::staticMetaObject, qt_meta_stringdata_DolphinTabWidget.data,
      qt_meta_data_DolphinTabWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *DolphinTabWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DolphinTabWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DolphinTabWidget.stringdata0))
        return static_cast<void*>(this);
    return QTabWidget::qt_metacast(_clname);
}

int DolphinTabWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void DolphinTabWidget::activeViewChanged(DolphinViewContainer * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DolphinTabWidget::tabCountChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void DolphinTabWidget::rememberClosedTab(const QUrl & _t1, const QByteArray & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void DolphinTabWidget::currentUrlChanged(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
