/****************************************************************************
** Meta object code from reading C++ file 'dolphinviewcontainer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/dolphin-17.08.3/src/dolphinviewcontainer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dolphinviewcontainer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DolphinViewContainer_t {
    QByteArrayData data[47];
    char stringdata0[772];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DolphinViewContainer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DolphinViewContainer_t qt_meta_stringdata_DolphinViewContainer = {
    {
QT_MOC_LITERAL(0, 0, 20), // "DolphinViewContainer"
QT_MOC_LITERAL(1, 21, 20), // "showFilterBarChanged"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 5), // "shown"
QT_MOC_LITERAL(4, 49, 17), // "writeStateChanged"
QT_MOC_LITERAL(5, 67, 16), // "isFolderWritable"
QT_MOC_LITERAL(6, 84, 6), // "setUrl"
QT_MOC_LITERAL(7, 91, 3), // "url"
QT_MOC_LITERAL(8, 95, 19), // "setFilterBarVisible"
QT_MOC_LITERAL(9, 115, 7), // "visible"
QT_MOC_LITERAL(10, 123, 22), // "delayedStatusBarUpdate"
QT_MOC_LITERAL(11, 146, 15), // "updateStatusBar"
QT_MOC_LITERAL(12, 162, 30), // "updateDirectoryLoadingProgress"
QT_MOC_LITERAL(13, 193, 7), // "percent"
QT_MOC_LITERAL(14, 201, 30), // "updateDirectorySortingProgress"
QT_MOC_LITERAL(15, 232, 27), // "slotDirectoryLoadingStarted"
QT_MOC_LITERAL(16, 260, 29), // "slotDirectoryLoadingCompleted"
QT_MOC_LITERAL(17, 290, 28), // "slotDirectoryLoadingCanceled"
QT_MOC_LITERAL(18, 319, 18), // "slotUrlIsFileError"
QT_MOC_LITERAL(19, 338, 17), // "slotItemActivated"
QT_MOC_LITERAL(20, 356, 9), // "KFileItem"
QT_MOC_LITERAL(21, 366, 4), // "item"
QT_MOC_LITERAL(22, 371, 18), // "slotItemsActivated"
QT_MOC_LITERAL(23, 390, 13), // "KFileItemList"
QT_MOC_LITERAL(24, 404, 5), // "items"
QT_MOC_LITERAL(25, 410, 12), // "showItemInfo"
QT_MOC_LITERAL(26, 423, 14), // "closeFilterBar"
QT_MOC_LITERAL(27, 438, 13), // "setNameFilter"
QT_MOC_LITERAL(28, 452, 10), // "nameFilter"
QT_MOC_LITERAL(29, 463, 8), // "activate"
QT_MOC_LITERAL(30, 472, 40), // "slotUrlNavigatorLocationAbout..."
QT_MOC_LITERAL(31, 513, 31), // "slotUrlNavigatorLocationChanged"
QT_MOC_LITERAL(32, 545, 8), // "redirect"
QT_MOC_LITERAL(33, 554, 6), // "oldUrl"
QT_MOC_LITERAL(34, 561, 6), // "newUrl"
QT_MOC_LITERAL(35, 568, 12), // "requestFocus"
QT_MOC_LITERAL(36, 581, 21), // "saveUrlCompletionMode"
QT_MOC_LITERAL(37, 603, 27), // "KCompletion::CompletionMode"
QT_MOC_LITERAL(38, 631, 10), // "completion"
QT_MOC_LITERAL(39, 642, 17), // "slotReturnPressed"
QT_MOC_LITERAL(40, 660, 14), // "startSearching"
QT_MOC_LITERAL(41, 675, 14), // "closeSearchBox"
QT_MOC_LITERAL(42, 690, 20), // "stopDirectoryLoading"
QT_MOC_LITERAL(43, 711, 29), // "slotStatusBarZoomLevelChanged"
QT_MOC_LITERAL(44, 741, 9), // "zoomLevel"
QT_MOC_LITERAL(45, 751, 16), // "showErrorMessage"
QT_MOC_LITERAL(46, 768, 3) // "msg"

    },
    "DolphinViewContainer\0showFilterBarChanged\0"
    "\0shown\0writeStateChanged\0isFolderWritable\0"
    "setUrl\0url\0setFilterBarVisible\0visible\0"
    "delayedStatusBarUpdate\0updateStatusBar\0"
    "updateDirectoryLoadingProgress\0percent\0"
    "updateDirectorySortingProgress\0"
    "slotDirectoryLoadingStarted\0"
    "slotDirectoryLoadingCompleted\0"
    "slotDirectoryLoadingCanceled\0"
    "slotUrlIsFileError\0slotItemActivated\0"
    "KFileItem\0item\0slotItemsActivated\0"
    "KFileItemList\0items\0showItemInfo\0"
    "closeFilterBar\0setNameFilter\0nameFilter\0"
    "activate\0slotUrlNavigatorLocationAboutToBeChanged\0"
    "slotUrlNavigatorLocationChanged\0"
    "redirect\0oldUrl\0newUrl\0requestFocus\0"
    "saveUrlCompletionMode\0KCompletion::CompletionMode\0"
    "completion\0slotReturnPressed\0"
    "startSearching\0closeSearchBox\0"
    "stopDirectoryLoading\0slotStatusBarZoomLevelChanged\0"
    "zoomLevel\0showErrorMessage\0msg"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DolphinViewContainer[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      29,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  159,    2, 0x06 /* Public */,
       4,    1,  162,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,  165,    2, 0x0a /* Public */,
       8,    1,  168,    2, 0x0a /* Public */,
      10,    0,  171,    2, 0x08 /* Private */,
      11,    0,  172,    2, 0x08 /* Private */,
      12,    1,  173,    2, 0x08 /* Private */,
      14,    1,  176,    2, 0x08 /* Private */,
      15,    0,  179,    2, 0x08 /* Private */,
      16,    0,  180,    2, 0x08 /* Private */,
      17,    0,  181,    2, 0x08 /* Private */,
      18,    1,  182,    2, 0x08 /* Private */,
      19,    1,  185,    2, 0x08 /* Private */,
      22,    1,  188,    2, 0x08 /* Private */,
      25,    1,  191,    2, 0x08 /* Private */,
      26,    0,  194,    2, 0x08 /* Private */,
      27,    1,  195,    2, 0x08 /* Private */,
      29,    0,  198,    2, 0x08 /* Private */,
      30,    1,  199,    2, 0x08 /* Private */,
      31,    1,  202,    2, 0x08 /* Private */,
      32,    2,  205,    2, 0x08 /* Private */,
      35,    0,  210,    2, 0x08 /* Private */,
      36,    1,  211,    2, 0x08 /* Private */,
      39,    0,  214,    2, 0x08 /* Private */,
      40,    0,  215,    2, 0x08 /* Private */,
      41,    0,  216,    2, 0x08 /* Private */,
      42,    0,  217,    2, 0x08 /* Private */,
      43,    1,  218,    2, 0x08 /* Private */,
      45,    1,  221,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    5,

 // slots: parameters
    QMetaType::Void, QMetaType::QUrl,    7,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl,    7,
    QMetaType::Void, 0x80000000 | 20,   21,
    QMetaType::Void, 0x80000000 | 23,   24,
    QMetaType::Void, 0x80000000 | 20,   21,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   28,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl,    7,
    QMetaType::Void, QMetaType::QUrl,    7,
    QMetaType::Void, QMetaType::QUrl, QMetaType::QUrl,   33,   34,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 37,   38,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   44,
    QMetaType::Void, QMetaType::QString,   46,

       0        // eod
};

void DolphinViewContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DolphinViewContainer *_t = static_cast<DolphinViewContainer *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->showFilterBarChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->writeStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->setUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 3: _t->setFilterBarVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->delayedStatusBarUpdate(); break;
        case 5: _t->updateStatusBar(); break;
        case 6: _t->updateDirectoryLoadingProgress((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->updateDirectorySortingProgress((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->slotDirectoryLoadingStarted(); break;
        case 9: _t->slotDirectoryLoadingCompleted(); break;
        case 10: _t->slotDirectoryLoadingCanceled(); break;
        case 11: _t->slotUrlIsFileError((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 12: _t->slotItemActivated((*reinterpret_cast< const KFileItem(*)>(_a[1]))); break;
        case 13: _t->slotItemsActivated((*reinterpret_cast< const KFileItemList(*)>(_a[1]))); break;
        case 14: _t->showItemInfo((*reinterpret_cast< const KFileItem(*)>(_a[1]))); break;
        case 15: _t->closeFilterBar(); break;
        case 16: _t->setNameFilter((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 17: _t->activate(); break;
        case 18: _t->slotUrlNavigatorLocationAboutToBeChanged((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 19: _t->slotUrlNavigatorLocationChanged((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 20: _t->redirect((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2]))); break;
        case 21: _t->requestFocus(); break;
        case 22: _t->saveUrlCompletionMode((*reinterpret_cast< KCompletion::CompletionMode(*)>(_a[1]))); break;
        case 23: _t->slotReturnPressed(); break;
        case 24: _t->startSearching(); break;
        case 25: _t->closeSearchBox(); break;
        case 26: _t->stopDirectoryLoading(); break;
        case 27: _t->slotStatusBarZoomLevelChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 28: _t->showErrorMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KFileItem >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KFileItem >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (DolphinViewContainer::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DolphinViewContainer::showFilterBarChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (DolphinViewContainer::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DolphinViewContainer::writeStateChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject DolphinViewContainer::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_DolphinViewContainer.data,
      qt_meta_data_DolphinViewContainer,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *DolphinViewContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DolphinViewContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DolphinViewContainer.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int DolphinViewContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void DolphinViewContainer::showFilterBarChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DolphinViewContainer::writeStateChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
