/****************************************************************************
** Meta object code from reading C++ file 'kitemlistview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/dolphin-17.08.3/src/kitemviews/kitemlistview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QSet>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kitemlistview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KItemListView_t {
    QByteArrayData data[61];
    char stringdata0[1017];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KItemListView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KItemListView_t qt_meta_stringdata_KItemListView = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KItemListView"
QT_MOC_LITERAL(1, 14, 24), // "scrollOrientationChanged"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 15), // "Qt::Orientation"
QT_MOC_LITERAL(4, 56, 7), // "current"
QT_MOC_LITERAL(5, 64, 8), // "previous"
QT_MOC_LITERAL(6, 73, 19), // "scrollOffsetChanged"
QT_MOC_LITERAL(7, 93, 26), // "maximumScrollOffsetChanged"
QT_MOC_LITERAL(8, 120, 17), // "itemOffsetChanged"
QT_MOC_LITERAL(9, 138, 24), // "maximumItemOffsetChanged"
QT_MOC_LITERAL(10, 163, 8), // "scrollTo"
QT_MOC_LITERAL(11, 172, 9), // "newOffset"
QT_MOC_LITERAL(12, 182, 16), // "sortOrderChanged"
QT_MOC_LITERAL(13, 199, 13), // "Qt::SortOrder"
QT_MOC_LITERAL(14, 213, 15), // "sortRoleChanged"
QT_MOC_LITERAL(15, 229, 19), // "visibleRolesChanged"
QT_MOC_LITERAL(16, 249, 19), // "roleEditingCanceled"
QT_MOC_LITERAL(17, 269, 5), // "index"
QT_MOC_LITERAL(18, 275, 4), // "role"
QT_MOC_LITERAL(19, 280, 5), // "value"
QT_MOC_LITERAL(20, 286, 19), // "roleEditingFinished"
QT_MOC_LITERAL(21, 306, 17), // "slotItemsInserted"
QT_MOC_LITERAL(22, 324, 14), // "KItemRangeList"
QT_MOC_LITERAL(23, 339, 10), // "itemRanges"
QT_MOC_LITERAL(24, 350, 16), // "slotItemsRemoved"
QT_MOC_LITERAL(25, 367, 14), // "slotItemsMoved"
QT_MOC_LITERAL(26, 382, 10), // "KItemRange"
QT_MOC_LITERAL(27, 393, 9), // "itemRange"
QT_MOC_LITERAL(28, 403, 10), // "QList<int>"
QT_MOC_LITERAL(29, 414, 14), // "movedToIndexes"
QT_MOC_LITERAL(30, 429, 16), // "slotItemsChanged"
QT_MOC_LITERAL(31, 446, 16), // "QSet<QByteArray>"
QT_MOC_LITERAL(32, 463, 5), // "roles"
QT_MOC_LITERAL(33, 469, 17), // "slotGroupsChanged"
QT_MOC_LITERAL(34, 487, 25), // "slotGroupedSortingChanged"
QT_MOC_LITERAL(35, 513, 20), // "slotSortOrderChanged"
QT_MOC_LITERAL(36, 534, 19), // "slotSortRoleChanged"
QT_MOC_LITERAL(37, 554, 18), // "slotCurrentChanged"
QT_MOC_LITERAL(38, 573, 20), // "slotSelectionChanged"
QT_MOC_LITERAL(39, 594, 8), // "KItemSet"
QT_MOC_LITERAL(40, 603, 21), // "slotAnimationFinished"
QT_MOC_LITERAL(41, 625, 16), // "QGraphicsWidget*"
QT_MOC_LITERAL(42, 642, 6), // "widget"
QT_MOC_LITERAL(43, 649, 37), // "KItemListViewAnimation::Anima..."
QT_MOC_LITERAL(44, 687, 4), // "type"
QT_MOC_LITERAL(45, 692, 23), // "slotLayoutTimerFinished"
QT_MOC_LITERAL(46, 716, 24), // "slotRubberBandPosChanged"
QT_MOC_LITERAL(47, 741, 31), // "slotRubberBandActivationChanged"
QT_MOC_LITERAL(48, 773, 6), // "active"
QT_MOC_LITERAL(49, 780, 28), // "slotHeaderColumnWidthChanged"
QT_MOC_LITERAL(50, 809, 12), // "currentWidth"
QT_MOC_LITERAL(51, 822, 13), // "previousWidth"
QT_MOC_LITERAL(52, 836, 21), // "slotHeaderColumnMoved"
QT_MOC_LITERAL(53, 858, 12), // "currentIndex"
QT_MOC_LITERAL(54, 871, 13), // "previousIndex"
QT_MOC_LITERAL(55, 885, 20), // "triggerAutoScrolling"
QT_MOC_LITERAL(56, 906, 38), // "slotGeometryOfGroupHeaderPare..."
QT_MOC_LITERAL(57, 945, 23), // "slotRoleEditingCanceled"
QT_MOC_LITERAL(58, 969, 23), // "slotRoleEditingFinished"
QT_MOC_LITERAL(59, 993, 12), // "scrollOffset"
QT_MOC_LITERAL(60, 1006, 10) // "itemOffset"

    },
    "KItemListView\0scrollOrientationChanged\0"
    "\0Qt::Orientation\0current\0previous\0"
    "scrollOffsetChanged\0maximumScrollOffsetChanged\0"
    "itemOffsetChanged\0maximumItemOffsetChanged\0"
    "scrollTo\0newOffset\0sortOrderChanged\0"
    "Qt::SortOrder\0sortRoleChanged\0"
    "visibleRolesChanged\0roleEditingCanceled\0"
    "index\0role\0value\0roleEditingFinished\0"
    "slotItemsInserted\0KItemRangeList\0"
    "itemRanges\0slotItemsRemoved\0slotItemsMoved\0"
    "KItemRange\0itemRange\0QList<int>\0"
    "movedToIndexes\0slotItemsChanged\0"
    "QSet<QByteArray>\0roles\0slotGroupsChanged\0"
    "slotGroupedSortingChanged\0"
    "slotSortOrderChanged\0slotSortRoleChanged\0"
    "slotCurrentChanged\0slotSelectionChanged\0"
    "KItemSet\0slotAnimationFinished\0"
    "QGraphicsWidget*\0widget\0"
    "KItemListViewAnimation::AnimationType\0"
    "type\0slotLayoutTimerFinished\0"
    "slotRubberBandPosChanged\0"
    "slotRubberBandActivationChanged\0active\0"
    "slotHeaderColumnWidthChanged\0currentWidth\0"
    "previousWidth\0slotHeaderColumnMoved\0"
    "currentIndex\0previousIndex\0"
    "triggerAutoScrolling\0"
    "slotGeometryOfGroupHeaderParentChanged\0"
    "slotRoleEditingCanceled\0slotRoleEditingFinished\0"
    "scrollOffset\0itemOffset"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KItemListView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      31,   14, // methods
       2,  306, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      11,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  169,    2, 0x06 /* Public */,
       6,    2,  174,    2, 0x06 /* Public */,
       7,    2,  179,    2, 0x06 /* Public */,
       8,    2,  184,    2, 0x06 /* Public */,
       9,    2,  189,    2, 0x06 /* Public */,
      10,    1,  194,    2, 0x06 /* Public */,
      12,    2,  197,    2, 0x06 /* Public */,
      14,    2,  202,    2, 0x06 /* Public */,
      15,    2,  207,    2, 0x06 /* Public */,
      16,    3,  212,    2, 0x06 /* Public */,
      20,    3,  219,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      21,    1,  226,    2, 0x09 /* Protected */,
      24,    1,  229,    2, 0x09 /* Protected */,
      25,    2,  232,    2, 0x09 /* Protected */,
      30,    2,  237,    2, 0x09 /* Protected */,
      33,    0,  242,    2, 0x09 /* Protected */,
      34,    1,  243,    2, 0x09 /* Protected */,
      35,    2,  246,    2, 0x09 /* Protected */,
      36,    2,  251,    2, 0x09 /* Protected */,
      37,    2,  256,    2, 0x09 /* Protected */,
      38,    2,  261,    2, 0x09 /* Protected */,
      40,    2,  266,    2, 0x08 /* Private */,
      45,    0,  271,    2, 0x08 /* Private */,
      46,    0,  272,    2, 0x08 /* Private */,
      47,    1,  273,    2, 0x08 /* Private */,
      49,    3,  276,    2, 0x08 /* Private */,
      52,    3,  283,    2, 0x08 /* Private */,
      55,    0,  290,    2, 0x08 /* Private */,
      56,    0,  291,    2, 0x08 /* Private */,
      57,    3,  292,    2, 0x08 /* Private */,
      58,    3,  299,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,    4,    5,
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,    4,    5,
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,    4,    5,
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,    4,    5,
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,    4,    5,
    QMetaType::Void, QMetaType::QReal,   11,
    QMetaType::Void, 0x80000000 | 13, 0x80000000 | 13,    4,    5,
    QMetaType::Void, QMetaType::QByteArray, QMetaType::QByteArray,    4,    5,
    QMetaType::Void, QMetaType::QByteArrayList, QMetaType::QByteArrayList,    4,    5,
    QMetaType::Void, QMetaType::Int, QMetaType::QByteArray, QMetaType::QVariant,   17,   18,   19,
    QMetaType::Void, QMetaType::Int, QMetaType::QByteArray, QMetaType::QVariant,   17,   18,   19,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 22,   23,
    QMetaType::Void, 0x80000000 | 22,   23,
    QMetaType::Void, 0x80000000 | 26, 0x80000000 | 28,   27,   29,
    QMetaType::Void, 0x80000000 | 22, 0x80000000 | 31,   23,   32,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, 0x80000000 | 13, 0x80000000 | 13,    4,    5,
    QMetaType::Void, QMetaType::QByteArray, QMetaType::QByteArray,    4,    5,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    4,    5,
    QMetaType::Void, 0x80000000 | 39, 0x80000000 | 39,    4,    5,
    QMetaType::Void, 0x80000000 | 41, 0x80000000 | 43,   42,   44,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   48,
    QMetaType::Void, QMetaType::QByteArray, QMetaType::QReal, QMetaType::QReal,   18,   50,   51,
    QMetaType::Void, QMetaType::QByteArray, QMetaType::Int, QMetaType::Int,   18,   53,   54,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QByteArray, QMetaType::QVariant,   17,   18,   19,
    QMetaType::Void, QMetaType::Int, QMetaType::QByteArray, QMetaType::QVariant,   17,   18,   19,

 // properties: name, type, flags
      59, QMetaType::QReal, 0x00095103,
      60, QMetaType::QReal, 0x00095103,

       0        // eod
};

void KItemListView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KItemListView *_t = static_cast<KItemListView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->scrollOrientationChanged((*reinterpret_cast< Qt::Orientation(*)>(_a[1])),(*reinterpret_cast< Qt::Orientation(*)>(_a[2]))); break;
        case 1: _t->scrollOffsetChanged((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 2: _t->maximumScrollOffsetChanged((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 3: _t->itemOffsetChanged((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 4: _t->maximumItemOffsetChanged((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 5: _t->scrollTo((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 6: _t->sortOrderChanged((*reinterpret_cast< Qt::SortOrder(*)>(_a[1])),(*reinterpret_cast< Qt::SortOrder(*)>(_a[2]))); break;
        case 7: _t->sortRoleChanged((*reinterpret_cast< const QByteArray(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 8: _t->visibleRolesChanged((*reinterpret_cast< const QList<QByteArray>(*)>(_a[1])),(*reinterpret_cast< const QList<QByteArray>(*)>(_a[2]))); break;
        case 9: _t->roleEditingCanceled((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2])),(*reinterpret_cast< const QVariant(*)>(_a[3]))); break;
        case 10: _t->roleEditingFinished((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2])),(*reinterpret_cast< const QVariant(*)>(_a[3]))); break;
        case 11: _t->slotItemsInserted((*reinterpret_cast< const KItemRangeList(*)>(_a[1]))); break;
        case 12: _t->slotItemsRemoved((*reinterpret_cast< const KItemRangeList(*)>(_a[1]))); break;
        case 13: _t->slotItemsMoved((*reinterpret_cast< const KItemRange(*)>(_a[1])),(*reinterpret_cast< const QList<int>(*)>(_a[2]))); break;
        case 14: _t->slotItemsChanged((*reinterpret_cast< const KItemRangeList(*)>(_a[1])),(*reinterpret_cast< const QSet<QByteArray>(*)>(_a[2]))); break;
        case 15: _t->slotGroupsChanged(); break;
        case 16: _t->slotGroupedSortingChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->slotSortOrderChanged((*reinterpret_cast< Qt::SortOrder(*)>(_a[1])),(*reinterpret_cast< Qt::SortOrder(*)>(_a[2]))); break;
        case 18: _t->slotSortRoleChanged((*reinterpret_cast< const QByteArray(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 19: _t->slotCurrentChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 20: _t->slotSelectionChanged((*reinterpret_cast< const KItemSet(*)>(_a[1])),(*reinterpret_cast< const KItemSet(*)>(_a[2]))); break;
        case 21: _t->slotAnimationFinished((*reinterpret_cast< QGraphicsWidget*(*)>(_a[1])),(*reinterpret_cast< KItemListViewAnimation::AnimationType(*)>(_a[2]))); break;
        case 22: _t->slotLayoutTimerFinished(); break;
        case 23: _t->slotRubberBandPosChanged(); break;
        case 24: _t->slotRubberBandActivationChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 25: _t->slotHeaderColumnWidthChanged((*reinterpret_cast< const QByteArray(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2])),(*reinterpret_cast< qreal(*)>(_a[3]))); break;
        case 26: _t->slotHeaderColumnMoved((*reinterpret_cast< const QByteArray(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 27: _t->triggerAutoScrolling(); break;
        case 28: _t->slotGeometryOfGroupHeaderParentChanged(); break;
        case 29: _t->slotRoleEditingCanceled((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2])),(*reinterpret_cast< const QVariant(*)>(_a[3]))); break;
        case 30: _t->slotRoleEditingFinished((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2])),(*reinterpret_cast< const QVariant(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QSet<QByteArray> >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QGraphicsWidget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KItemListView::*_t)(Qt::Orientation , Qt::Orientation );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListView::scrollOrientationChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KItemListView::*_t)(qreal , qreal );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListView::scrollOffsetChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KItemListView::*_t)(qreal , qreal );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListView::maximumScrollOffsetChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KItemListView::*_t)(qreal , qreal );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListView::itemOffsetChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KItemListView::*_t)(qreal , qreal );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListView::maximumItemOffsetChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KItemListView::*_t)(qreal );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListView::scrollTo)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KItemListView::*_t)(Qt::SortOrder , Qt::SortOrder );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListView::sortOrderChanged)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (KItemListView::*_t)(const QByteArray & , const QByteArray & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListView::sortRoleChanged)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (KItemListView::*_t)(const QList<QByteArray> & , const QList<QByteArray> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListView::visibleRolesChanged)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (KItemListView::*_t)(int , const QByteArray & , const QVariant & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListView::roleEditingCanceled)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (KItemListView::*_t)(int , const QByteArray & , const QVariant & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListView::roleEditingFinished)) {
                *result = 10;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KItemListView *_t = static_cast<KItemListView *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qreal*>(_v) = _t->scrollOffset(); break;
        case 1: *reinterpret_cast< qreal*>(_v) = _t->itemOffset(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KItemListView *_t = static_cast<KItemListView *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setScrollOffset(*reinterpret_cast< qreal*>(_v)); break;
        case 1: _t->setItemOffset(*reinterpret_cast< qreal*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KItemListView::staticMetaObject = {
    { &QGraphicsWidget::staticMetaObject, qt_meta_stringdata_KItemListView.data,
      qt_meta_data_KItemListView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KItemListView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KItemListView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KItemListView.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsWidget::qt_metacast(_clname);
}

int KItemListView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KItemListView::scrollOrientationChanged(Qt::Orientation _t1, Qt::Orientation _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KItemListView::scrollOffsetChanged(qreal _t1, qreal _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KItemListView::maximumScrollOffsetChanged(qreal _t1, qreal _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KItemListView::itemOffsetChanged(qreal _t1, qreal _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KItemListView::maximumItemOffsetChanged(qreal _t1, qreal _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KItemListView::scrollTo(qreal _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KItemListView::sortOrderChanged(Qt::SortOrder _t1, Qt::SortOrder _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KItemListView::sortRoleChanged(const QByteArray & _t1, const QByteArray & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void KItemListView::visibleRolesChanged(const QList<QByteArray> & _t1, const QList<QByteArray> & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void KItemListView::roleEditingCanceled(int _t1, const QByteArray & _t2, const QVariant & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void KItemListView::roleEditingFinished(int _t1, const QByteArray & _t2, const QVariant & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
