/****************************************************************************
** Meta object code from reading C++ file 'kfileitemmodelrolesupdater.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/dolphin-17.08.3/src/kitemviews/kfileitemmodelrolesupdater.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QSet>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kfileitemmodelrolesupdater.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KFileItemModelRolesUpdater_t {
    QByteArrayData data[34];
    char stringdata0[506];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KFileItemModelRolesUpdater_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KFileItemModelRolesUpdater_t qt_meta_stringdata_KFileItemModelRolesUpdater = {
    {
QT_MOC_LITERAL(0, 0, 26), // "KFileItemModelRolesUpdater"
QT_MOC_LITERAL(1, 27, 17), // "slotItemsInserted"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 14), // "KItemRangeList"
QT_MOC_LITERAL(4, 61, 10), // "itemRanges"
QT_MOC_LITERAL(5, 72, 16), // "slotItemsRemoved"
QT_MOC_LITERAL(6, 89, 14), // "slotItemsMoved"
QT_MOC_LITERAL(7, 104, 10), // "KItemRange"
QT_MOC_LITERAL(8, 115, 9), // "itemRange"
QT_MOC_LITERAL(9, 125, 10), // "QList<int>"
QT_MOC_LITERAL(10, 136, 14), // "movedToIndexes"
QT_MOC_LITERAL(11, 151, 16), // "slotItemsChanged"
QT_MOC_LITERAL(12, 168, 16), // "QSet<QByteArray>"
QT_MOC_LITERAL(13, 185, 5), // "roles"
QT_MOC_LITERAL(14, 191, 19), // "slotSortRoleChanged"
QT_MOC_LITERAL(15, 211, 7), // "current"
QT_MOC_LITERAL(16, 219, 8), // "previous"
QT_MOC_LITERAL(17, 228, 14), // "slotGotPreview"
QT_MOC_LITERAL(18, 243, 9), // "KFileItem"
QT_MOC_LITERAL(19, 253, 4), // "item"
QT_MOC_LITERAL(20, 258, 6), // "pixmap"
QT_MOC_LITERAL(21, 265, 17), // "slotPreviewFailed"
QT_MOC_LITERAL(22, 283, 22), // "slotPreviewJobFinished"
QT_MOC_LITERAL(23, 306, 19), // "slotOverlaysChanged"
QT_MOC_LITERAL(24, 326, 3), // "url"
QT_MOC_LITERAL(25, 330, 19), // "resolveNextSortRole"
QT_MOC_LITERAL(26, 350, 23), // "resolveNextPendingRoles"
QT_MOC_LITERAL(27, 374, 27), // "resolveRecentlyChangedItems"
QT_MOC_LITERAL(28, 402, 22), // "applyChangedBalooRoles"
QT_MOC_LITERAL(29, 425, 4), // "file"
QT_MOC_LITERAL(30, 430, 29), // "applyChangedBalooRolesForItem"
QT_MOC_LITERAL(31, 460, 34), // "slotDirectoryContentsCountRec..."
QT_MOC_LITERAL(32, 495, 4), // "path"
QT_MOC_LITERAL(33, 500, 5) // "count"

    },
    "KFileItemModelRolesUpdater\0slotItemsInserted\0"
    "\0KItemRangeList\0itemRanges\0slotItemsRemoved\0"
    "slotItemsMoved\0KItemRange\0itemRange\0"
    "QList<int>\0movedToIndexes\0slotItemsChanged\0"
    "QSet<QByteArray>\0roles\0slotSortRoleChanged\0"
    "current\0previous\0slotGotPreview\0"
    "KFileItem\0item\0pixmap\0slotPreviewFailed\0"
    "slotPreviewJobFinished\0slotOverlaysChanged\0"
    "url\0resolveNextSortRole\0resolveNextPendingRoles\0"
    "resolveRecentlyChangedItems\0"
    "applyChangedBalooRoles\0file\0"
    "applyChangedBalooRolesForItem\0"
    "slotDirectoryContentsCountReceived\0"
    "path\0count"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KFileItemModelRolesUpdater[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   89,    2, 0x08 /* Private */,
       5,    1,   92,    2, 0x08 /* Private */,
       6,    2,   95,    2, 0x08 /* Private */,
      11,    2,  100,    2, 0x08 /* Private */,
      14,    2,  105,    2, 0x08 /* Private */,
      17,    2,  110,    2, 0x08 /* Private */,
      21,    1,  115,    2, 0x08 /* Private */,
      22,    0,  118,    2, 0x08 /* Private */,
      23,    2,  119,    2, 0x08 /* Private */,
      25,    0,  124,    2, 0x08 /* Private */,
      26,    0,  125,    2, 0x08 /* Private */,
      27,    0,  126,    2, 0x08 /* Private */,
      28,    1,  127,    2, 0x08 /* Private */,
      30,    1,  130,    2, 0x08 /* Private */,
      31,    2,  133,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 9,    8,   10,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 12,    4,   13,
    QMetaType::Void, QMetaType::QByteArray, QMetaType::QByteArray,   15,   16,
    QMetaType::Void, 0x80000000 | 18, QMetaType::QPixmap,   19,   20,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl, QMetaType::QStringList,   24,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   29,
    QMetaType::Void, 0x80000000 | 18,   29,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,   32,   33,

       0        // eod
};

void KFileItemModelRolesUpdater::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KFileItemModelRolesUpdater *_t = static_cast<KFileItemModelRolesUpdater *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotItemsInserted((*reinterpret_cast< const KItemRangeList(*)>(_a[1]))); break;
        case 1: _t->slotItemsRemoved((*reinterpret_cast< const KItemRangeList(*)>(_a[1]))); break;
        case 2: _t->slotItemsMoved((*reinterpret_cast< const KItemRange(*)>(_a[1])),(*reinterpret_cast< QList<int>(*)>(_a[2]))); break;
        case 3: _t->slotItemsChanged((*reinterpret_cast< const KItemRangeList(*)>(_a[1])),(*reinterpret_cast< const QSet<QByteArray>(*)>(_a[2]))); break;
        case 4: _t->slotSortRoleChanged((*reinterpret_cast< const QByteArray(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 5: _t->slotGotPreview((*reinterpret_cast< const KFileItem(*)>(_a[1])),(*reinterpret_cast< const QPixmap(*)>(_a[2]))); break;
        case 6: _t->slotPreviewFailed((*reinterpret_cast< const KFileItem(*)>(_a[1]))); break;
        case 7: _t->slotPreviewJobFinished(); break;
        case 8: _t->slotOverlaysChanged((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 9: _t->resolveNextSortRole(); break;
        case 10: _t->resolveNextPendingRoles(); break;
        case 11: _t->resolveRecentlyChangedItems(); break;
        case 12: _t->applyChangedBalooRoles((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->applyChangedBalooRolesForItem((*reinterpret_cast< const KFileItem(*)>(_a[1]))); break;
        case 14: _t->slotDirectoryContentsCountReceived((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QSet<QByteArray> >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KFileItem >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KFileItem >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KFileItem >(); break;
            }
            break;
        }
    }
}

const QMetaObject KFileItemModelRolesUpdater::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KFileItemModelRolesUpdater.data,
      qt_meta_data_KFileItemModelRolesUpdater,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KFileItemModelRolesUpdater::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KFileItemModelRolesUpdater::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KFileItemModelRolesUpdater.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KFileItemModelRolesUpdater::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
