/****************************************************************************
** Meta object code from reading C++ file 'kitemlistcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/dolphin-17.08.3/src/kitemviews/kitemlistcontroller.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kitemlistcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KItemListController_t {
    QByteArrayData data[48];
    char stringdata0[758];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KItemListController_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KItemListController_t qt_meta_stringdata_KItemListController = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KItemListController"
QT_MOC_LITERAL(1, 20, 13), // "itemActivated"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 5), // "index"
QT_MOC_LITERAL(4, 41, 14), // "itemsActivated"
QT_MOC_LITERAL(5, 56, 8), // "KItemSet"
QT_MOC_LITERAL(6, 65, 7), // "indexes"
QT_MOC_LITERAL(7, 73, 17), // "itemMiddleClicked"
QT_MOC_LITERAL(8, 91, 24), // "itemContextMenuRequested"
QT_MOC_LITERAL(9, 116, 3), // "pos"
QT_MOC_LITERAL(10, 120, 24), // "viewContextMenuRequested"
QT_MOC_LITERAL(11, 145, 26), // "headerContextMenuRequested"
QT_MOC_LITERAL(12, 172, 11), // "itemHovered"
QT_MOC_LITERAL(13, 184, 13), // "itemUnhovered"
QT_MOC_LITERAL(14, 198, 18), // "mouseButtonPressed"
QT_MOC_LITERAL(15, 217, 9), // "itemIndex"
QT_MOC_LITERAL(16, 227, 16), // "Qt::MouseButtons"
QT_MOC_LITERAL(17, 244, 7), // "buttons"
QT_MOC_LITERAL(18, 252, 19), // "mouseButtonReleased"
QT_MOC_LITERAL(19, 272, 26), // "itemExpansionToggleClicked"
QT_MOC_LITERAL(20, 299, 13), // "itemDropEvent"
QT_MOC_LITERAL(21, 313, 28), // "QGraphicsSceneDragDropEvent*"
QT_MOC_LITERAL(22, 342, 5), // "event"
QT_MOC_LITERAL(23, 348, 18), // "aboveItemDropEvent"
QT_MOC_LITERAL(24, 367, 13), // "escapePressed"
QT_MOC_LITERAL(25, 381, 12), // "modelChanged"
QT_MOC_LITERAL(26, 394, 15), // "KItemModelBase*"
QT_MOC_LITERAL(27, 410, 7), // "current"
QT_MOC_LITERAL(28, 418, 8), // "previous"
QT_MOC_LITERAL(29, 427, 11), // "viewChanged"
QT_MOC_LITERAL(30, 439, 14), // "KItemListView*"
QT_MOC_LITERAL(31, 454, 27), // "slotViewScrollOffsetChanged"
QT_MOC_LITERAL(32, 482, 21), // "slotRubberBandChanged"
QT_MOC_LITERAL(33, 504, 21), // "slotChangeCurrentItem"
QT_MOC_LITERAL(34, 526, 4), // "text"
QT_MOC_LITERAL(35, 531, 18), // "searchFromNextItem"
QT_MOC_LITERAL(36, 550, 25), // "slotAutoActivationTimeout"
QT_MOC_LITERAL(37, 576, 5), // "model"
QT_MOC_LITERAL(38, 582, 4), // "view"
QT_MOC_LITERAL(39, 587, 17), // "selectionBehavior"
QT_MOC_LITERAL(40, 605, 17), // "SelectionBehavior"
QT_MOC_LITERAL(41, 623, 22), // "autoActivationBehavior"
QT_MOC_LITERAL(42, 646, 22), // "AutoActivationBehavior"
QT_MOC_LITERAL(43, 669, 22), // "mouseDoubleClickAction"
QT_MOC_LITERAL(44, 692, 22), // "MouseDoubleClickAction"
QT_MOC_LITERAL(45, 715, 11), // "NoSelection"
QT_MOC_LITERAL(46, 727, 15), // "SingleSelection"
QT_MOC_LITERAL(47, 743, 14) // "MultiSelection"

    },
    "KItemListController\0itemActivated\0\0"
    "index\0itemsActivated\0KItemSet\0indexes\0"
    "itemMiddleClicked\0itemContextMenuRequested\0"
    "pos\0viewContextMenuRequested\0"
    "headerContextMenuRequested\0itemHovered\0"
    "itemUnhovered\0mouseButtonPressed\0"
    "itemIndex\0Qt::MouseButtons\0buttons\0"
    "mouseButtonReleased\0itemExpansionToggleClicked\0"
    "itemDropEvent\0QGraphicsSceneDragDropEvent*\0"
    "event\0aboveItemDropEvent\0escapePressed\0"
    "modelChanged\0KItemModelBase*\0current\0"
    "previous\0viewChanged\0KItemListView*\0"
    "slotViewScrollOffsetChanged\0"
    "slotRubberBandChanged\0slotChangeCurrentItem\0"
    "text\0searchFromNextItem\0"
    "slotAutoActivationTimeout\0model\0view\0"
    "selectionBehavior\0SelectionBehavior\0"
    "autoActivationBehavior\0AutoActivationBehavior\0"
    "mouseDoubleClickAction\0MouseDoubleClickAction\0"
    "NoSelection\0SingleSelection\0MultiSelection"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KItemListController[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       5,  186, // properties
       1,  201, // enums/sets
       0,    0, // constructors
       0,       // flags
      16,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  114,    2, 0x06 /* Public */,
       4,    1,  117,    2, 0x06 /* Public */,
       7,    1,  120,    2, 0x06 /* Public */,
       8,    2,  123,    2, 0x06 /* Public */,
      10,    1,  128,    2, 0x06 /* Public */,
      11,    1,  131,    2, 0x06 /* Public */,
      12,    1,  134,    2, 0x06 /* Public */,
      13,    1,  137,    2, 0x06 /* Public */,
      14,    2,  140,    2, 0x06 /* Public */,
      18,    2,  145,    2, 0x06 /* Public */,
      19,    1,  150,    2, 0x06 /* Public */,
      20,    2,  153,    2, 0x06 /* Public */,
      23,    2,  158,    2, 0x06 /* Public */,
      24,    0,  163,    2, 0x06 /* Public */,
      25,    2,  164,    2, 0x06 /* Public */,
      29,    2,  169,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      31,    2,  174,    2, 0x08 /* Private */,
      32,    0,  179,    2, 0x08 /* Private */,
      33,    2,  180,    2, 0x08 /* Private */,
      36,    0,  185,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, QMetaType::QPointF,    3,    9,
    QMetaType::Void, QMetaType::QPointF,    9,
    QMetaType::Void, QMetaType::QPointF,    9,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 16,   15,   17,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 16,   15,   17,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 21,    3,   22,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 21,    3,   22,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 26, 0x80000000 | 26,   27,   28,
    QMetaType::Void, 0x80000000 | 30, 0x80000000 | 30,   27,   28,

 // slots: parameters
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,   27,   28,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,   34,   35,
    QMetaType::Void,

 // properties: name, type, flags
      37, 0x80000000 | 26, 0x0009510b,
      38, 0x80000000 | 30, 0x0009510b,
      39, 0x80000000 | 40, 0x0009510b,
      41, 0x80000000 | 42, 0x0009510b,
      43, 0x80000000 | 44, 0x0009510b,

 // enums: name, flags, count, data
      40, 0x0,    3,  205,

 // enum data: key, value
      45, uint(KItemListController::NoSelection),
      46, uint(KItemListController::SingleSelection),
      47, uint(KItemListController::MultiSelection),

       0        // eod
};

void KItemListController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KItemListController *_t = static_cast<KItemListController *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->itemActivated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->itemsActivated((*reinterpret_cast< const KItemSet(*)>(_a[1]))); break;
        case 2: _t->itemMiddleClicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->itemContextMenuRequested((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QPointF(*)>(_a[2]))); break;
        case 4: _t->viewContextMenuRequested((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 5: _t->headerContextMenuRequested((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 6: _t->itemHovered((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->itemUnhovered((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->mouseButtonPressed((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Qt::MouseButtons(*)>(_a[2]))); break;
        case 9: _t->mouseButtonReleased((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Qt::MouseButtons(*)>(_a[2]))); break;
        case 10: _t->itemExpansionToggleClicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->itemDropEvent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QGraphicsSceneDragDropEvent*(*)>(_a[2]))); break;
        case 12: _t->aboveItemDropEvent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QGraphicsSceneDragDropEvent*(*)>(_a[2]))); break;
        case 13: _t->escapePressed(); break;
        case 14: _t->modelChanged((*reinterpret_cast< KItemModelBase*(*)>(_a[1])),(*reinterpret_cast< KItemModelBase*(*)>(_a[2]))); break;
        case 15: _t->viewChanged((*reinterpret_cast< KItemListView*(*)>(_a[1])),(*reinterpret_cast< KItemListView*(*)>(_a[2]))); break;
        case 16: _t->slotViewScrollOffsetChanged((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 17: _t->slotRubberBandChanged(); break;
        case 18: _t->slotChangeCurrentItem((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 19: _t->slotAutoActivationTimeout(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KItemListController::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::itemActivated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KItemListController::*_t)(const KItemSet & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::itemsActivated)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KItemListController::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::itemMiddleClicked)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KItemListController::*_t)(int , const QPointF & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::itemContextMenuRequested)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KItemListController::*_t)(const QPointF & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::viewContextMenuRequested)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KItemListController::*_t)(const QPointF & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::headerContextMenuRequested)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KItemListController::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::itemHovered)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (KItemListController::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::itemUnhovered)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (KItemListController::*_t)(int , Qt::MouseButtons );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::mouseButtonPressed)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (KItemListController::*_t)(int , Qt::MouseButtons );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::mouseButtonReleased)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (KItemListController::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::itemExpansionToggleClicked)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (KItemListController::*_t)(int , QGraphicsSceneDragDropEvent * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::itemDropEvent)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (KItemListController::*_t)(int , QGraphicsSceneDragDropEvent * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::aboveItemDropEvent)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (KItemListController::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::escapePressed)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (KItemListController::*_t)(KItemModelBase * , KItemModelBase * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::modelChanged)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (KItemListController::*_t)(KItemListView * , KItemListView * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KItemListController::viewChanged)) {
                *result = 15;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KItemListController *_t = static_cast<KItemListController *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< KItemModelBase**>(_v) = _t->model(); break;
        case 1: *reinterpret_cast< KItemListView**>(_v) = _t->view(); break;
        case 2: *reinterpret_cast< SelectionBehavior*>(_v) = _t->selectionBehavior(); break;
        case 3: *reinterpret_cast< AutoActivationBehavior*>(_v) = _t->autoActivationBehavior(); break;
        case 4: *reinterpret_cast< MouseDoubleClickAction*>(_v) = _t->mouseDoubleClickAction(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KItemListController *_t = static_cast<KItemListController *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setModel(*reinterpret_cast< KItemModelBase**>(_v)); break;
        case 1: _t->setView(*reinterpret_cast< KItemListView**>(_v)); break;
        case 2: _t->setSelectionBehavior(*reinterpret_cast< SelectionBehavior*>(_v)); break;
        case 3: _t->setAutoActivationBehavior(*reinterpret_cast< AutoActivationBehavior*>(_v)); break;
        case 4: _t->setMouseDoubleClickAction(*reinterpret_cast< MouseDoubleClickAction*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KItemListController::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KItemListController.data,
      qt_meta_data_KItemListController,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KItemListController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KItemListController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KItemListController.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KItemListController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 20;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 5;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KItemListController::itemActivated(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KItemListController::itemsActivated(const KItemSet & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KItemListController::itemMiddleClicked(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KItemListController::itemContextMenuRequested(int _t1, const QPointF & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KItemListController::viewContextMenuRequested(const QPointF & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KItemListController::headerContextMenuRequested(const QPointF & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KItemListController::itemHovered(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KItemListController::itemUnhovered(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void KItemListController::mouseButtonPressed(int _t1, Qt::MouseButtons _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void KItemListController::mouseButtonReleased(int _t1, Qt::MouseButtons _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void KItemListController::itemExpansionToggleClicked(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void KItemListController::itemDropEvent(int _t1, QGraphicsSceneDragDropEvent * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void KItemListController::aboveItemDropEvent(int _t1, QGraphicsSceneDragDropEvent * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void KItemListController::escapePressed()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KItemListController::modelChanged(KItemModelBase * _t1, KItemModelBase * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void KItemListController::viewChanged(KItemListView * _t1, KItemListView * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
