/****************************************************************************
** Meta object code from reading C++ file 'dolphinviewactionhandler.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/dolphin-17.08.3/src/views/dolphinviewactionhandler.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dolphinviewactionhandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DolphinViewActionHandler_t {
    QByteArrayData data[40];
    char stringdata0[665];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DolphinViewActionHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DolphinViewActionHandler_t qt_meta_stringdata_DolphinViewActionHandler = {
    {
QT_MOC_LITERAL(0, 0, 24), // "DolphinViewActionHandler"
QT_MOC_LITERAL(1, 25, 18), // "actionBeingHandled"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 15), // "createDirectory"
QT_MOC_LITERAL(4, 61, 17), // "updateViewActions"
QT_MOC_LITERAL(5, 79, 27), // "slotViewModeActionTriggered"
QT_MOC_LITERAL(6, 107, 8), // "QAction*"
QT_MOC_LITERAL(7, 116, 10), // "slotRename"
QT_MOC_LITERAL(8, 127, 18), // "slotTrashActivated"
QT_MOC_LITERAL(9, 146, 15), // "slotDeleteItems"
QT_MOC_LITERAL(10, 162, 13), // "togglePreview"
QT_MOC_LITERAL(11, 176, 24), // "slotPreviewsShownChanged"
QT_MOC_LITERAL(12, 201, 5), // "shown"
QT_MOC_LITERAL(13, 207, 6), // "zoomIn"
QT_MOC_LITERAL(14, 214, 7), // "zoomOut"
QT_MOC_LITERAL(15, 222, 15), // "toggleSortOrder"
QT_MOC_LITERAL(16, 238, 22), // "toggleSortFoldersFirst"
QT_MOC_LITERAL(17, 261, 20), // "slotSortOrderChanged"
QT_MOC_LITERAL(18, 282, 13), // "Qt::SortOrder"
QT_MOC_LITERAL(19, 296, 5), // "order"
QT_MOC_LITERAL(20, 302, 27), // "slotSortFoldersFirstChanged"
QT_MOC_LITERAL(21, 330, 12), // "foldersFirst"
QT_MOC_LITERAL(22, 343, 19), // "slotSortRoleChanged"
QT_MOC_LITERAL(23, 363, 4), // "role"
QT_MOC_LITERAL(24, 368, 20), // "slotZoomLevelChanged"
QT_MOC_LITERAL(25, 389, 7), // "current"
QT_MOC_LITERAL(26, 397, 8), // "previous"
QT_MOC_LITERAL(27, 406, 17), // "toggleVisibleRole"
QT_MOC_LITERAL(28, 424, 6), // "action"
QT_MOC_LITERAL(29, 431, 17), // "slotSortTriggered"
QT_MOC_LITERAL(30, 449, 23), // "slotVisibleRolesChanged"
QT_MOC_LITERAL(31, 473, 20), // "toggleGroupedSorting"
QT_MOC_LITERAL(32, 494, 25), // "slotGroupedSortingChanged"
QT_MOC_LITERAL(33, 520, 15), // "sortCategorized"
QT_MOC_LITERAL(34, 536, 21), // "toggleShowHiddenFiles"
QT_MOC_LITERAL(35, 558, 27), // "slotHiddenFilesShownChanged"
QT_MOC_LITERAL(36, 586, 21), // "slotWriteStateChanged"
QT_MOC_LITERAL(37, 608, 16), // "isFolderWritable"
QT_MOC_LITERAL(38, 625, 24), // "slotAdjustViewProperties"
QT_MOC_LITERAL(39, 650, 14) // "slotProperties"

    },
    "DolphinViewActionHandler\0actionBeingHandled\0"
    "\0createDirectory\0updateViewActions\0"
    "slotViewModeActionTriggered\0QAction*\0"
    "slotRename\0slotTrashActivated\0"
    "slotDeleteItems\0togglePreview\0"
    "slotPreviewsShownChanged\0shown\0zoomIn\0"
    "zoomOut\0toggleSortOrder\0toggleSortFoldersFirst\0"
    "slotSortOrderChanged\0Qt::SortOrder\0"
    "order\0slotSortFoldersFirstChanged\0"
    "foldersFirst\0slotSortRoleChanged\0role\0"
    "slotZoomLevelChanged\0current\0previous\0"
    "toggleVisibleRole\0action\0slotSortTriggered\0"
    "slotVisibleRolesChanged\0toggleGroupedSorting\0"
    "slotGroupedSortingChanged\0sortCategorized\0"
    "toggleShowHiddenFiles\0slotHiddenFilesShownChanged\0"
    "slotWriteStateChanged\0isFolderWritable\0"
    "slotAdjustViewProperties\0slotProperties"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DolphinViewActionHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      27,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  149,    2, 0x06 /* Public */,
       3,    0,  150,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,  151,    2, 0x0a /* Public */,
       5,    1,  152,    2, 0x08 /* Private */,
       7,    0,  155,    2, 0x08 /* Private */,
       8,    0,  156,    2, 0x08 /* Private */,
       9,    0,  157,    2, 0x08 /* Private */,
      10,    1,  158,    2, 0x08 /* Private */,
      11,    1,  161,    2, 0x08 /* Private */,
      13,    0,  164,    2, 0x08 /* Private */,
      14,    0,  165,    2, 0x08 /* Private */,
      15,    0,  166,    2, 0x08 /* Private */,
      16,    0,  167,    2, 0x08 /* Private */,
      17,    1,  168,    2, 0x08 /* Private */,
      20,    1,  171,    2, 0x08 /* Private */,
      22,    1,  174,    2, 0x08 /* Private */,
      24,    2,  177,    2, 0x08 /* Private */,
      27,    1,  182,    2, 0x08 /* Private */,
      29,    1,  185,    2, 0x08 /* Private */,
      30,    2,  188,    2, 0x08 /* Private */,
      31,    1,  193,    2, 0x08 /* Private */,
      32,    1,  196,    2, 0x08 /* Private */,
      34,    1,  199,    2, 0x08 /* Private */,
      35,    1,  202,    2, 0x08 /* Private */,
      36,    1,  205,    2, 0x08 /* Private */,
      38,    0,  208,    2, 0x08 /* Private */,
      39,    0,  209,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void, QMetaType::Bool,   21,
    QMetaType::Void, QMetaType::QByteArray,   23,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   25,   26,
    QMetaType::Void, 0x80000000 | 6,   28,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, QMetaType::QByteArrayList, QMetaType::QByteArrayList,   25,   26,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,   33,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void, QMetaType::Bool,   37,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void DolphinViewActionHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DolphinViewActionHandler *_t = static_cast<DolphinViewActionHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->actionBeingHandled(); break;
        case 1: _t->createDirectory(); break;
        case 2: _t->updateViewActions(); break;
        case 3: _t->slotViewModeActionTriggered((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 4: _t->slotRename(); break;
        case 5: _t->slotTrashActivated(); break;
        case 6: _t->slotDeleteItems(); break;
        case 7: _t->togglePreview((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->slotPreviewsShownChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->zoomIn(); break;
        case 10: _t->zoomOut(); break;
        case 11: _t->toggleSortOrder(); break;
        case 12: _t->toggleSortFoldersFirst(); break;
        case 13: _t->slotSortOrderChanged((*reinterpret_cast< Qt::SortOrder(*)>(_a[1]))); break;
        case 14: _t->slotSortFoldersFirstChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->slotSortRoleChanged((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 16: _t->slotZoomLevelChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 17: _t->toggleVisibleRole((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 18: _t->slotSortTriggered((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 19: _t->slotVisibleRolesChanged((*reinterpret_cast< const QList<QByteArray>(*)>(_a[1])),(*reinterpret_cast< const QList<QByteArray>(*)>(_a[2]))); break;
        case 20: _t->toggleGroupedSorting((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->slotGroupedSortingChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 22: _t->toggleShowHiddenFiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 23: _t->slotHiddenFilesShownChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 24: _t->slotWriteStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 25: _t->slotAdjustViewProperties(); break;
        case 26: _t->slotProperties(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (DolphinViewActionHandler::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DolphinViewActionHandler::actionBeingHandled)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (DolphinViewActionHandler::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DolphinViewActionHandler::createDirectory)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject DolphinViewActionHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_DolphinViewActionHandler.data,
      qt_meta_data_DolphinViewActionHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *DolphinViewActionHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DolphinViewActionHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DolphinViewActionHandler.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DolphinViewActionHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 27;
    }
    return _id;
}

// SIGNAL 0
void DolphinViewActionHandler::actionBeingHandled()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DolphinViewActionHandler::createDirectory()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
