/****************************************************************************
** Meta object code from reading C++ file 'kdirectorycontentscounterworker.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/dolphin-17.08.3/src/kitemviews/private/kdirectorycontentscounterworker.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kdirectorycontentscounterworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KDirectoryContentsCounterWorker_t {
    QByteArrayData data[8];
    char stringdata0[123];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KDirectoryContentsCounterWorker_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KDirectoryContentsCounterWorker_t qt_meta_stringdata_KDirectoryContentsCounterWorker = {
    {
QT_MOC_LITERAL(0, 0, 31), // "KDirectoryContentsCounterWorker"
QT_MOC_LITERAL(1, 32, 6), // "result"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 4), // "path"
QT_MOC_LITERAL(4, 45, 5), // "count"
QT_MOC_LITERAL(5, 51, 22), // "countDirectoryContents"
QT_MOC_LITERAL(6, 74, 40), // "KDirectoryContentsCounterWork..."
QT_MOC_LITERAL(7, 115, 7) // "options"

    },
    "KDirectoryContentsCounterWorker\0result\0"
    "\0path\0count\0countDirectoryContents\0"
    "KDirectoryContentsCounterWorker::Options\0"
    "options"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KDirectoryContentsCounterWorker[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   24,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    2,   29,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    3,    4,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, 0x80000000 | 6,    3,    7,

       0        // eod
};

void KDirectoryContentsCounterWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KDirectoryContentsCounterWorker *_t = static_cast<KDirectoryContentsCounterWorker *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->result((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->countDirectoryContents((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< KDirectoryContentsCounterWorker::Options(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KDirectoryContentsCounterWorker::Options >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KDirectoryContentsCounterWorker::*_t)(const QString & , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KDirectoryContentsCounterWorker::result)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KDirectoryContentsCounterWorker::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KDirectoryContentsCounterWorker.data,
      qt_meta_data_KDirectoryContentsCounterWorker,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KDirectoryContentsCounterWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDirectoryContentsCounterWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KDirectoryContentsCounterWorker.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDirectoryContentsCounterWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KDirectoryContentsCounterWorker::result(const QString & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
