/****************************************************************************
** Meta object code from reading C++ file 'dolphinpart.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/dolphin-17.08.3/src/dolphinpart.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dolphinpart.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DolphinPart_t {
    QByteArrayData data[48];
    char stringdata0[652];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DolphinPart_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DolphinPart_t qt_meta_stringdata_DolphinPart = {
    {
QT_MOC_LITERAL(0, 0, 11), // "DolphinPart"
QT_MOC_LITERAL(1, 12, 15), // "viewModeChanged"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 14), // "aboutToOpenURL"
QT_MOC_LITERAL(4, 44, 11), // "slotMessage"
QT_MOC_LITERAL(5, 56, 3), // "msg"
QT_MOC_LITERAL(6, 60, 16), // "slotErrorMessage"
QT_MOC_LITERAL(7, 77, 19), // "slotRequestItemInfo"
QT_MOC_LITERAL(8, 97, 9), // "KFileItem"
QT_MOC_LITERAL(9, 107, 4), // "item"
QT_MOC_LITERAL(10, 112, 17), // "slotItemActivated"
QT_MOC_LITERAL(11, 130, 18), // "slotItemsActivated"
QT_MOC_LITERAL(12, 149, 13), // "KFileItemList"
QT_MOC_LITERAL(13, 163, 5), // "items"
QT_MOC_LITERAL(14, 169, 15), // "createNewWindow"
QT_MOC_LITERAL(15, 185, 3), // "url"
QT_MOC_LITERAL(16, 189, 19), // "slotOpenContextMenu"
QT_MOC_LITERAL(17, 209, 3), // "pos"
QT_MOC_LITERAL(18, 213, 15), // "QList<QAction*>"
QT_MOC_LITERAL(19, 229, 13), // "customActions"
QT_MOC_LITERAL(20, 243, 24), // "slotDirectoryRedirection"
QT_MOC_LITERAL(21, 268, 6), // "oldUrl"
QT_MOC_LITERAL(22, 275, 6), // "newUrl"
QT_MOC_LITERAL(23, 282, 20), // "slotSelectionChanged"
QT_MOC_LITERAL(24, 303, 9), // "selection"
QT_MOC_LITERAL(25, 313, 17), // "updatePasteAction"
QT_MOC_LITERAL(26, 331, 15), // "slotGoTriggered"
QT_MOC_LITERAL(27, 347, 8), // "QAction*"
QT_MOC_LITERAL(28, 356, 6), // "action"
QT_MOC_LITERAL(29, 363, 16), // "slotEditMimeType"
QT_MOC_LITERAL(30, 380, 30), // "slotSelectItemsMatchingPattern"
QT_MOC_LITERAL(31, 411, 32), // "slotUnselectItemsMatchingPattern"
QT_MOC_LITERAL(32, 444, 16), // "slotOpenTerminal"
QT_MOC_LITERAL(33, 461, 12), // "slotFindFile"
QT_MOC_LITERAL(34, 474, 13), // "updateNewMenu"
QT_MOC_LITERAL(35, 488, 15), // "updateStatusBar"
QT_MOC_LITERAL(36, 504, 14), // "updateProgress"
QT_MOC_LITERAL(37, 519, 7), // "percent"
QT_MOC_LITERAL(38, 527, 15), // "createDirectory"
QT_MOC_LITERAL(39, 543, 16), // "setFilesToSelect"
QT_MOC_LITERAL(40, 560, 11), // "QList<QUrl>"
QT_MOC_LITERAL(41, 572, 5), // "files"
QT_MOC_LITERAL(42, 578, 13), // "filesToSelect"
QT_MOC_LITERAL(43, 592, 11), // "eventFilter"
QT_MOC_LITERAL(44, 604, 7), // "QEvent*"
QT_MOC_LITERAL(45, 612, 12), // "supportsUndo"
QT_MOC_LITERAL(46, 625, 15), // "currentViewMode"
QT_MOC_LITERAL(47, 641, 10) // "nameFilter"

    },
    "DolphinPart\0viewModeChanged\0\0"
    "aboutToOpenURL\0slotMessage\0msg\0"
    "slotErrorMessage\0slotRequestItemInfo\0"
    "KFileItem\0item\0slotItemActivated\0"
    "slotItemsActivated\0KFileItemList\0items\0"
    "createNewWindow\0url\0slotOpenContextMenu\0"
    "pos\0QList<QAction*>\0customActions\0"
    "slotDirectoryRedirection\0oldUrl\0newUrl\0"
    "slotSelectionChanged\0selection\0"
    "updatePasteAction\0slotGoTriggered\0"
    "QAction*\0action\0slotEditMimeType\0"
    "slotSelectItemsMatchingPattern\0"
    "slotUnselectItemsMatchingPattern\0"
    "slotOpenTerminal\0slotFindFile\0"
    "updateNewMenu\0updateStatusBar\0"
    "updateProgress\0percent\0createDirectory\0"
    "setFilesToSelect\0QList<QUrl>\0files\0"
    "filesToSelect\0eventFilter\0QEvent*\0"
    "supportsUndo\0currentViewMode\0nameFilter"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DolphinPart[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      25,   14, // methods
       4,  200, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  139,    2, 0x06 /* Public */,
       3,    0,  140,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,  141,    2, 0x08 /* Private */,
       6,    1,  144,    2, 0x08 /* Private */,
       7,    1,  147,    2, 0x08 /* Private */,
      10,    1,  150,    2, 0x08 /* Private */,
      11,    1,  153,    2, 0x08 /* Private */,
      14,    1,  156,    2, 0x08 /* Private */,
      16,    4,  159,    2, 0x08 /* Private */,
      20,    2,  168,    2, 0x08 /* Private */,
      23,    1,  173,    2, 0x08 /* Private */,
      25,    0,  176,    2, 0x08 /* Private */,
      26,    1,  177,    2, 0x08 /* Private */,
      29,    0,  180,    2, 0x08 /* Private */,
      30,    0,  181,    2, 0x08 /* Private */,
      31,    0,  182,    2, 0x08 /* Private */,
      32,    0,  183,    2, 0x08 /* Private */,
      33,    0,  184,    2, 0x08 /* Private */,
      34,    0,  185,    2, 0x08 /* Private */,
      35,    0,  186,    2, 0x08 /* Private */,
      36,    1,  187,    2, 0x08 /* Private */,
      38,    0,  190,    2, 0x08 /* Private */,
      39,    1,  191,    2, 0x08 /* Private */,
      42,    0,  194,    2, 0x08 /* Private */,
      43,    2,  195,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, QMetaType::QUrl,   15,
    QMetaType::Void, QMetaType::QPoint, 0x80000000 | 8, QMetaType::QUrl, 0x80000000 | 18,   17,    9,   15,   19,
    QMetaType::Void, QMetaType::QUrl, QMetaType::QUrl,   21,   22,
    QMetaType::Void, 0x80000000 | 12,   24,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 27,   28,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   37,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 40,   41,
    0x80000000 | 40,
    QMetaType::Bool, QMetaType::QObjectStar, 0x80000000 | 44,    2,    2,

 // properties: name, type, flags
      45, QMetaType::Bool, 0x00095001,
      46, QMetaType::QString, 0x00095103,
      47, QMetaType::QString, 0x00095103,
      42, 0x80000000 | 40, 0x0009510b,

       0        // eod
};

void DolphinPart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DolphinPart *_t = static_cast<DolphinPart *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->viewModeChanged(); break;
        case 1: _t->aboutToOpenURL(); break;
        case 2: _t->slotMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->slotErrorMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->slotRequestItemInfo((*reinterpret_cast< const KFileItem(*)>(_a[1]))); break;
        case 5: _t->slotItemActivated((*reinterpret_cast< const KFileItem(*)>(_a[1]))); break;
        case 6: _t->slotItemsActivated((*reinterpret_cast< const KFileItemList(*)>(_a[1]))); break;
        case 7: _t->createNewWindow((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 8: _t->slotOpenContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1])),(*reinterpret_cast< const KFileItem(*)>(_a[2])),(*reinterpret_cast< const QUrl(*)>(_a[3])),(*reinterpret_cast< const QList<QAction*>(*)>(_a[4]))); break;
        case 9: _t->slotDirectoryRedirection((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2]))); break;
        case 10: _t->slotSelectionChanged((*reinterpret_cast< const KFileItemList(*)>(_a[1]))); break;
        case 11: _t->updatePasteAction(); break;
        case 12: _t->slotGoTriggered((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 13: _t->slotEditMimeType(); break;
        case 14: _t->slotSelectItemsMatchingPattern(); break;
        case 15: _t->slotUnselectItemsMatchingPattern(); break;
        case 16: _t->slotOpenTerminal(); break;
        case 17: _t->slotFindFile(); break;
        case 18: _t->updateNewMenu(); break;
        case 19: _t->updateStatusBar(); break;
        case 20: _t->updateProgress((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 21: _t->createDirectory(); break;
        case 22: _t->setFilesToSelect((*reinterpret_cast< const QList<QUrl>(*)>(_a[1]))); break;
        case 23: { QList<QUrl> _r = _t->filesToSelect();
            if (_a[0]) *reinterpret_cast< QList<QUrl>*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->eventFilter((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< QEvent*(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (DolphinPart::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DolphinPart::viewModeChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (DolphinPart::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DolphinPart::aboutToOpenURL)) {
                *result = 1;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        DolphinPart *_t = static_cast<DolphinPart *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->supportsUndo(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->currentViewMode(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->nameFilter(); break;
        case 3: *reinterpret_cast< QList<QUrl>*>(_v) = _t->filesToSelect(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        DolphinPart *_t = static_cast<DolphinPart *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setCurrentViewMode(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setNameFilter(*reinterpret_cast< QString*>(_v)); break;
        case 3: _t->setFilesToSelect(*reinterpret_cast< QList<QUrl>*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject DolphinPart::staticMetaObject = {
    { &KParts::ReadOnlyPart::staticMetaObject, qt_meta_stringdata_DolphinPart.data,
      qt_meta_data_DolphinPart,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *DolphinPart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DolphinPart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DolphinPart.stringdata0))
        return static_cast<void*>(this);
    return KParts::ReadOnlyPart::qt_metacast(_clname);
}

int DolphinPart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadOnlyPart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 4;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void DolphinPart::viewModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DolphinPart::aboutToOpenURL()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
