// This file is generated by kconfig_compiler_kf5 from dolphin_placespanelsettings.kcfg.
// All changes you do to this file will be lost.

#include "dolphin_placespanelsettings.h"

#include <qglobal.h>
#include <QtCore/QFile>

class PlacesPanelSettingsHelper
{
  public:
    PlacesPanelSettingsHelper() : q(nullptr) {}
    ~PlacesPanelSettingsHelper() { delete q; }
    PlacesPanelSettings *q;
};
Q_GLOBAL_STATIC(PlacesPanelSettingsHelper, s_globalPlacesPanelSettings)
PlacesPanelSettings *PlacesPanelSettings::self()
{
  if (!s_globalPlacesPanelSettings()->q) {
    new PlacesPanelSettings;
    s_globalPlacesPanelSettings()->q->read();
  }

  return s_globalPlacesPanelSettings()->q;
}

PlacesPanelSettings::PlacesPanelSettings(  )
  : KConfigSkeleton( QStringLiteral( "dolphinrc" ) )
{
  Q_ASSERT(!s_globalPlacesPanelSettings()->q);
  s_globalPlacesPanelSettings()->q = this;
  setCurrentGroup( QStringLiteral( "PlacesPanel" ) );

  KConfigSkeleton::ItemInt  *itemIconSize;
  itemIconSize = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "IconSize" ), mIconSize, -1 );
  addItem( itemIconSize, QStringLiteral( "IconSize" ) );
}

PlacesPanelSettings::~PlacesPanelSettings()
{
  s_globalPlacesPanelSettings()->q = nullptr;
}

