/****************************************************************************
** Meta object code from reading C++ file 'kitemlistcontainer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/dolphin-17.08.3/src/kitemviews/kitemlistcontainer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kitemlistcontainer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KItemListContainer_t {
    QByteArrayData data[14];
    char stringdata0[216];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KItemListContainer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KItemListContainer_t qt_meta_stringdata_KItemListContainer = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KItemListContainer"
QT_MOC_LITERAL(1, 19, 28), // "slotScrollOrientationChanged"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 15), // "Qt::Orientation"
QT_MOC_LITERAL(4, 65, 7), // "current"
QT_MOC_LITERAL(5, 73, 8), // "previous"
QT_MOC_LITERAL(6, 82, 16), // "slotModelChanged"
QT_MOC_LITERAL(7, 99, 15), // "KItemModelBase*"
QT_MOC_LITERAL(8, 115, 15), // "slotViewChanged"
QT_MOC_LITERAL(9, 131, 14), // "KItemListView*"
QT_MOC_LITERAL(10, 146, 8), // "scrollTo"
QT_MOC_LITERAL(11, 155, 6), // "offset"
QT_MOC_LITERAL(12, 162, 27), // "updateScrollOffsetScrollBar"
QT_MOC_LITERAL(13, 190, 25) // "updateItemOffsetScrollBar"

    },
    "KItemListContainer\0slotScrollOrientationChanged\0"
    "\0Qt::Orientation\0current\0previous\0"
    "slotModelChanged\0KItemModelBase*\0"
    "slotViewChanged\0KItemListView*\0scrollTo\0"
    "offset\0updateScrollOffsetScrollBar\0"
    "updateItemOffsetScrollBar"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KItemListContainer[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   44,    2, 0x08 /* Private */,
       6,    2,   49,    2, 0x08 /* Private */,
       8,    2,   54,    2, 0x08 /* Private */,
      10,    1,   59,    2, 0x08 /* Private */,
      12,    0,   62,    2, 0x08 /* Private */,
      13,    0,   63,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,    4,    5,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 7,    4,    5,
    QMetaType::Void, 0x80000000 | 9, 0x80000000 | 9,    4,    5,
    QMetaType::Void, QMetaType::QReal,   11,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KItemListContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KItemListContainer *_t = static_cast<KItemListContainer *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotScrollOrientationChanged((*reinterpret_cast< Qt::Orientation(*)>(_a[1])),(*reinterpret_cast< Qt::Orientation(*)>(_a[2]))); break;
        case 1: _t->slotModelChanged((*reinterpret_cast< KItemModelBase*(*)>(_a[1])),(*reinterpret_cast< KItemModelBase*(*)>(_a[2]))); break;
        case 2: _t->slotViewChanged((*reinterpret_cast< KItemListView*(*)>(_a[1])),(*reinterpret_cast< KItemListView*(*)>(_a[2]))); break;
        case 3: _t->scrollTo((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 4: _t->updateScrollOffsetScrollBar(); break;
        case 5: _t->updateItemOffsetScrollBar(); break;
        default: ;
        }
    }
}

const QMetaObject KItemListContainer::staticMetaObject = {
    { &QAbstractScrollArea::staticMetaObject, qt_meta_stringdata_KItemListContainer.data,
      qt_meta_data_KItemListContainer,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KItemListContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KItemListContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KItemListContainer.stringdata0))
        return static_cast<void*>(this);
    return QAbstractScrollArea::qt_metacast(_clname);
}

int KItemListContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractScrollArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
