// This file is generated by kconfig_compiler_kf5 from dolphin_informationpanelsettings.kcfg.
// All changes you do to this file will be lost.

#include "dolphin_informationpanelsettings.h"

#include <qglobal.h>
#include <QtCore/QFile>

class InformationPanelSettingsHelper
{
  public:
    InformationPanelSettingsHelper() : q(nullptr) {}
    ~InformationPanelSettingsHelper() { delete q; }
    InformationPanelSettings *q;
};
Q_GLOBAL_STATIC(InformationPanelSettingsHelper, s_globalInformationPanelSettings)
InformationPanelSettings *InformationPanelSettings::self()
{
  if (!s_globalInformationPanelSettings()->q) {
    new InformationPanelSettings;
    s_globalInformationPanelSettings()->q->read();
  }

  return s_globalInformationPanelSettings()->q;
}

InformationPanelSettings::InformationPanelSettings(  )
  : KConfigSkeleton( QStringLiteral( "dolphinrc" ) )
{
  Q_ASSERT(!s_globalInformationPanelSettings()->q);
  s_globalInformationPanelSettings()->q = this;
  setCurrentGroup( QStringLiteral( "InformationPanel" ) );

  KConfigSkeleton::ItemBool  *itemPreviewsShown;
  itemPreviewsShown = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "previewsShown" ), mPreviewsShown, true );
  addItem( itemPreviewsShown, QStringLiteral( "previewsShown" ) );
}

InformationPanelSettings::~InformationPanelSettings()
{
  s_globalInformationPanelSettings()->q = nullptr;
}

